# GenerateWord

This is a library for generating random words.

## Installation

You can install this library using pip:


pip install generateword


## Usage

Here's how you can use this library to generate random words:

python
import generateword

word1 = generateword.generate_word(5) # "xqkjl"
word2 = generateword.generate_word(8) # "rdyabhnm"